# - Config file for the sdformat14 package.
#
# For finding and loading sdformat14 from your project, type:
#
# find_package(sdformat14)
#
# This creates the following targets:
#
#   Core library target                     - sdformat14::sdformat14
#   Alternative target name                 - sdformat14::core
#   Core library + all requested components - sdformat14::requested
#
# Use target_link_libraries() to link your library or executable to one of the
# above targets.
#
# We also provide the following variables for backwards compatibility, but use
# of these is discouraged:
#
#   sdformat14_CORE_LIBRARY - Core library (actually contains sdformat14::core)
#   sdformat14_LIBRARIES    - All libraries to link against (actually contains sdformat14::requested).
#   sdformat14_INCLUDE_DIRS - Include directories for sdformat14 and its dependencies.
#
# We will also set sdformat14_FOUND to indicate that the package was found.
#
################################################################################

# We explicitly set the desired cmake version to ensure that the policy settings
# of users or of toolchains do not result in the wrong behavior for our modules.
# Note that the call to find_package(~) will PUSH a new policy stack before
# taking on these version settings, and then that stack will POP after the
# find_package(~) has exited, so this will not affect the cmake policy settings
# of a caller.
cmake_minimum_required(VERSION 3.10.2 FATAL_ERROR)

if(NOT sdformat14_FIND_QUIETLY)
  message(STATUS "Looking for sdformat14 -- found version 14.8.0")
endif()

if(sdformat14_CONFIG_INCLUDED)

  # Check that each of the components requested in this call to find_package(~)
  # have already been found.
  set(sdformat14_all_requested_components_found true)
  foreach(component ${sdformat14_FIND_COMPONENTS})
    if(NOT sdformat14-${component}_FOUND)
      set(sdformat14_all_requested_components_found false)
      break()
    endif()
  endforeach()

  # If this sdformat14-config.cmake file has been called before,
  # and all the requested components are already found, then exit early.
  if(sdformat14_all_requested_components_found)
    return()
  endif()
endif()
set(sdformat14_CONFIG_INCLUDED TRUE)

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)
# Find gz-cmake, because we need its modules in order to find the rest of
# our dependencies.
find_dependency(gz-cmake3)

# Set the REQUIRED flag for the find_package(~) calls on this project's
# dependencies.
if(sdformat14_FIND_REQUIRED)
  set(gz_package_required REQUIRED)
else()
  set(gz_package_required "")
endif()

# Set the QUIET flag for the find_package(~) calls on this project's
# dependencies.
if(sdformat14_FIND_QUIETLY)
  set(gz_package_quiet QUIET)
else()
  set(gz_package_quiet "")
endif()

# --------------------------------
# Find each required dependency of this project (if nothing is below, then the
# project has no external dependencies). We use find_package(~) instead of
# find_dependency(~) here so that we can support COMPONENT arguments.
#
# TODO: When we migrate to cmake-3.9+, change these to find_dependency(~),
#       because at that point the find_dependency(~) function will support
#       the COMPONENT argument.
if(NOT sdformat14_FIND_QUIETLY)
  message(STATUS "Searching for dependencies of sdformat14")
endif()
find_package(TINYXML2 ${gz_package_quiet} ${gz_package_required})
find_package(gz-math7 ${gz_package_quiet} ${gz_package_required})
find_package(gz-utils2 ${gz_package_quiet} ${gz_package_required} COMPONENTS cli)
# --------------------------------


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was gz-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/x86_64-linux-gnu/cmake/sdformat14" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

if(NOT TARGET sdformat14::sdformat14)
  include("${CMAKE_CURRENT_LIST_DIR}/sdformat14-targets.cmake")

  # Create a simplified imported target name for the core library.
  # You can link to this target instead of the core library.
  add_library(sdformat14::core INTERFACE IMPORTED)
  set_target_properties(sdformat14::core PROPERTIES
    INTERFACE_LINK_LIBRARIES sdformat14::sdformat14)
  # Note: In a future version of cmake, we can replace this with an ALIAS target

  # In case someone tries to link against the plain library name, we want to
  # intercept that and have them link against a target instead. This is
  # effectively the same as sdformat14::core, but it does not have the
  # benefit of unambiguously being a target name.
  add_library(sdformat14 INTERFACE IMPORTED)
  set_target_properties(sdformat14 PROPERTIES
    INTERFACE_LINK_LIBRARIES sdformat14::sdformat14)

endif()

# Create the "all" target if it does not already exist
if(NOT TARGET sdformat14::requested)
  add_library(sdformat14::requested INTERFACE IMPORTED)
endif()

# Link the core library to the "all" target. We set the property explicitly
# because target_link_libraries cannot be called on an imported target.
get_target_property(gz_all_components sdformat14::requested INTERFACE_LINK_LIBRARIES)
if(NOT gz_all_components)
  # If sdformat14::requested has not been given any libraries yet, then cmake will
  # set gz_all_components to gz_all_components-NOTFOUND, which is something we
  # should NOT pass into the INTERFACE_LINK_LIBRARIES property.
  set_target_properties(sdformat14::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "sdformat14::sdformat14")
else()
  set_target_properties(sdformat14::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${gz_all_components};sdformat14::sdformat14")
endif()

# Package variables. Note that sdformat14_LIBRARIES and sdformat14_CORE_LIBRARY
# contain imported targets, so sdformat14_INCLUDE_DIRS is never needed.
set(sdformat14_CORE_LIBRARY sdformat14::core)
set(sdformat14_LIBRARIES sdformat14::requested)

if (NOT sdformat14_INCLUDE_DIRS_OVERRIDE)
  set_and_check(sdformat14_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/gz/sdformat14")
else()
  set_and_check(sdformat14_INCLUDE_DIRS ${sdformat14_INCLUDE_DIRS_OVERRIDE})
endif()

# Backwards compatibility variables
set(SDFormat_LIBRARIES ${sdformat14_LIBRARIES})
set(SDFormat_INCLUDE_DIRS ${sdformat14_INCLUDE_DIRS})

# This macro is used by gz-cmake to automatically configure the pkgconfig
# files for Gazebo projects.
gz_pkg_config_entry(sdformat14 "sdformat14")

# Find each of the components requested by find_package(~)
foreach(component ${sdformat14_FIND_COMPONENTS})

  if(NOT sdformat14_FIND_QUIETLY)
    message(STATUS "Searching for <sdformat14> component [${component}]")
  endif()

  if(sdformat14_FIND_REQUIRED_${component})

    # Find the component package using find_dependency(~). If the user specified
    # REQUIRED or QUIET, those will automatically get forwarded to
    # find_dependency(~)
    find_dependency(sdformat14-${component} 14.8.0 EXACT)

  else()

    # If this is an optional component, use find_package(~) instead of
    # find_dependency(~) so we can ensure that the use of REQUIRED does not get
    # forwarded to it.
    find_package(sdformat14-${component} 14.8.0 EXACT ${gz_package_quiet})

  endif()

endforeach()

# Specify the doxygen tag file
set(SDFORMAT_DOXYGEN_TAGFILE "${PACKAGE_PREFIX_DIR}/share/gz/sdformat14/sdformat14.tag.xml")

# Specify the API url. This is where the doxygen tag file will resolve URLS to.
set(SDFORMAT_API_URL "https://gazebosim.org/api/sdformat/14")

# include all config extra files
set(_extras "")
foreach(_extra ${_extras})
  include("${sdformat14_DIR}/${_extra}")
endforeach()
